<?php

namespace Drupal\lb_tabs\Plugin\Layout;

use Drupal\Core\Form\FormStateInterface;

/**
 * A very advanced custom layout.
 *
 * @Layout(
 *   id = "lb_tabs_accordion",
 *   label = @Translation("Accordion"),
 *   category = @Translation("Effects"),
 *   path = "layouts/accordion",
 *   template = "accordion",
 *   library = "lb_tabs/accordion",
 * )
 */
class AccordionLayout extends LbTabsLayoutBase {

  /**
   * The HTML ID prefix.
   */
  const HTML_ID_PREFIX = 'lb_tabs_acc';

  /**
   * {@inheritDoc}
   */
  public function defaultConfiguration() {
    return parent::defaultConfiguration() + ['allow_multiple_open' => FALSE];
  }

  /**
   * {@inheritDoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);
    $form['allow_multiple_open'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Allow multiple open items'),
      '#description' => $this->t('If this is set, multiple items can be open. This implies second-click-closes.'),
      '#default_value' => $this->configuration['allow_multiple_open'],
    ];
    return $form;
  }

  /**
   * {@inheritDoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);
    $this->configuration['allow_multiple_open'] = $form_state->getValue('allow_multiple_open');
    if ($this->configuration['allow_multiple_open']) {
      $this->configuration['second_click_closes'] = TRUE;
    }
  }

}
